﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/ec2/EC2_EXPORTS.h>

namespace Aws {
namespace EC2 {
namespace Model {
enum class WeekDay { NOT_SET, sunday, monday, tuesday, wednesday, thursday, friday, saturday };

namespace WeekDayMapper {
AWS_EC2_API WeekDay GetWeekDayForName(const Aws::String& name);

AWS_EC2_API Aws::String GetNameForWeekDay(WeekDay value);
}  // namespace WeekDayMapper
}  // namespace Model
}  // namespace EC2
}  // namespace Aws
